@@ -844,14 +844,14 @@ class gdb(DataPlot,Utils):
             if (style_plt[it] == style_plt[it+1]).all():
                 continue
             else:
-                stop = it
+                stop = it + 1
                 start_stop.append([start,stop])
-                start = stop+1
+                start = stop
         # last entry
         if start_stop == []:
             start_stop.append([0,len(xdata_vec)])
         else:
-            start_stop.append([start_stop[len(start_stop)-1][1]+1,len(xdata_vec)])
+            start_stop.append([start_stop[len(start_stop)-1][1],len(xdata_vec)+1])
 
         # now append things to return variables
         grain_plt_xdata = []
@@ -860,7 +860,6 @@ class gdb(DataPlot,Utils):
         grain_plt_yerr  = []
         grain_plt_style = []
         for i in range(len(start_stop)):
-
             grain_plt_xdata.append(xdata_vec[start_stop[i][0]:start_stop[i][1]])
             grain_plt_ydata.append(ydata_vec[start_stop[i][0]:start_stop[i][1]])
             grain_plt_xerr.append(xdata_err[start_stop[i][0]:start_stop[i][1]])
